@@ -9,10 +9,14 @@ CFG_CREDENTIALS_DICT = {
     "ALVIN_PLATFORM_ID": "your_alvin_platform_id",
     "ALVIN_API_HOST": "https://app.alvin.ai",
     "ALVIN_UI_HOST": "https://app.alvin.ai",
-    "DEBUG": "true",
+    "DEBUG": "false",
     "GIT_COMPARE_BRANCH": "main",
     "DBT_ROOT_DIR": "",
+    "DBT_TARGET": "",
+    "DBT_PROFILES_DIR": "",
     "ROOT_DIR": "",
+    "DIALECT": "ansi",
+    "ALVIN_VERBOSE_LOG": "false",
 }
 USER_CONFIG_DIR = expanduser("~") + "/.alvin"
 USER_CONFIG = USER_CONFIG_DIR + "/alvin.cfg"
