@@ -9,9 +9,6 @@ from alvin_api_client.model.impact_analysis_query_request import (
     ImpactAnalysisQueryRequest,
 )
 from alvin_api_client.model.impact_analysis_request import ImpactAnalysisRequest
-from alvin_api_client.model.impact_analysis_validation_payload import (
-    ImpactAnalysisValidationPayload,
-)
 
 from alvin_cli.schemas.models import OutputFormat
 from alvin_cli.utils.api_client import default_api
@@ -22,36 +19,31 @@ from alvin_cli.utils.common_arguments import PLATFORM_ID
 from alvin_cli.utils.common_arguments import SAVE_TO_FILE
 from alvin_cli.utils.helper_functions import extract_dict
 from alvin_cli.utils.helper_functions import handle_print_exception
+from alvin_cli.utils.helper_functions import print_node_stats_impact_analysis
 from alvin_cli.utils.helper_functions import print_output_format
 from alvin_cli.utils.helper_functions import structure_impact_analysis_data
 from alvin_cli.utils.helper_functions import typer_secho_raise
 
 app = typer.Typer(add_completion=False)
 
-print("first release")
-
 
 def __setup_logging() -> None:
     logging.basicConfig(level=logging.INFO)
 
 
-# this should not be released as a command for now
-def check_dbt(
+@app.command("check-sql-files")
+def check_sql_files_from_dbt(
     sql_models: List[str] = typer.Argument(
         ...,
         help=typer.style(
-            "List of SQL files separated by space",
+            "List of SQL files from dbt model separated by space",
             fg=typer.colors.BRIGHT_GREEN,
             bold=True,
         ),
     ),
-    manifest_file: str = typer.Option(
-        "target/manifest.json",
-        help=typer.style("Manifest File", fg=typer.colors.BRIGHT_YELLOW, bold=True),
-    ),
 ) -> None:
     """Check SQL Impact Analysis"""
-    run_check_sql_impact_analysis(list(sql_models), manifest_file)
+    run_check_sql_impact_analysis(list(sql_models), "target/manifest.json")
 
 
 @app.command()
@@ -73,7 +65,7 @@ def raw_query(
 ) -> None:
     """Check Impact Analysis From Raw Query Entity"""
 
-    title = "Impact Analysis"
+    title = "Summary of Impacted Entities"
     if file_name == "":
         file_name = "impact_analysis"
 
@@ -88,25 +80,26 @@ def raw_query(
         )
 
         if query_validation_response["is_valid_query"]:
-            validation_payload = query_validation_response["validation_payload"]
-            request_in_impact_analysis = ImpactAnalysisValidationPayload(
-                query_type=validation_payload["query_type"],
-                parent_entity=validation_payload["parent_entity"],
-                parse_result=validation_payload["parse_result"],
-                query_entities=validation_payload["query_entities"],
+
+            impact_analysis_response = default_api.run_impact_node_query_api_v2_impact_analysis_query_string_nodes_post(
+                request_in_query_validate
             )
 
-            impact_analysis_response = default_api.get_impact_from_validation_payload_api_v2_impact_analysis_query_entities_post(
-                request_in_impact_analysis
-            )
-            structured_data = structure_impact_analysis_data(impact_analysis_response)
-            print_output_format(
-                data=structured_data,
-                table_title=title,
-                output=output,
-                file_name=file_name,
-                save_to_file=save_to_file,
-            )
+            print_node_stats_impact_analysis(impact_analysis_response)
+
+            if save_to_file:
+                structured_data = structure_impact_analysis_data(
+                    impact_analysis_data=impact_analysis_response,
+                )
+
+                print_output_format(
+                    data=structured_data,
+                    table_title=title,
+                    output=output,
+                    file_name=file_name,
+                    save_to_file=save_to_file,
+                )
+
         else:
             typer_secho_raise("Invalid query!", "RED")
             return
