@@ -39,9 +39,7 @@ console = Console()
 wide_console = Console(width=350)
 
 
-def check_sql_impact_analysis(
-    paths: Sequence[str], manifest: Dict[str, Any], platform_id: str
-) -> int:
+def check_sql_impact_analysis(paths: Sequence[str], manifest: Dict[str, Any]) -> int:
     report = ImpactAnalysisCLIReport(
         markdown_text=f"[![ALVIN](https://alvin-public-assets.s3.eu-central-1.amazonaws.com/"
         f"black-color-icon-xsmall.svg)"
@@ -80,9 +78,7 @@ def check_sql_impact_analysis(
     for model in models:
         # We run all, but we need to store if
         # any model execution failed
-        status_code = __process_model(
-            model, status_code, report, platform_id=platform_id
-        )
+        status_code = __process_model(model, status_code, report)
         if status_code:
             all_status_code = status_code
 
@@ -248,6 +244,10 @@ def __resolve_dbt_query(
                 {templated_str}
               )
             """
+
+    if settings.alvin_verbose_log:
+        print(f"DEBUG: dbt query as string \n\n {dbt_create_as_str}")
+
     return dbt_create_as_str
 
 
@@ -255,13 +255,13 @@ def __call_impact_analysis_api(
     dbt_create_as_str: str,
     node: Dict[str, Any],
     file_git_history: Optional[FileGitHistory],
-    platform_id: str,
 ) -> ImpactAnalysisResponse:
-
     impact_analysis_query_request = ImpactAnalysisQueryRequest(
         source_text=dbt_create_as_str
     )
-    impact_analysis_platform_request = ImpactAnalysisPlatformRequest(id=platform_id)
+    impact_analysis_platform_request = ImpactAnalysisPlatformRequest(
+        id=settings.alvin_platform_id
+    )
     impact_analysis_request = ImpactAnalysisRequest(
         query=impact_analysis_query_request, platform=impact_analysis_platform_request
     )
@@ -283,11 +283,20 @@ def __call_impact_analysis_api(
     response: ImpactAnalysisResponse = default_api.run_impact_node_query_api_v2_impact_analysis_query_string_nodes_post(
         impact_analysis_request
     )
+
+    if settings.alvin_verbose_log:
+        print(
+            f"DEBUG: The impact analysis request sent is \n\n {impact_analysis_request}"
+        )
+        print(f"DEBUG: The impact analysis response received is \n\n {response}")
+
     return response
 
 
 def __process_model(
-    model: Model, status_code: int, report: ImpactAnalysisCLIReport, platform_id: str
+    model: Model,
+    status_code: int,
+    report: ImpactAnalysisCLIReport,
 ) -> int:
     node = model.node
 
@@ -305,9 +314,7 @@ def __process_model(
             original_file_path, relation_name, node["config"]
         )
 
-        response = __call_impact_analysis_api(
-            dbt_create_as_str, node, None, platform_id=platform_id
-        )
+        response = __call_impact_analysis_api(dbt_create_as_str, node, None)
 
         console.print(f"Changed Entity: [underline]{relation_name}", style="bold")
 
@@ -315,8 +322,8 @@ def __process_model(
         query_report = impact_analysis_response.query_report
 
         report.markdown_text = report.markdown_text + f"\n## {relation_name}"
-
         if query_report:
+
             query_report_url_code = query_report.query_report_url_code
             report_url = __create_report_url(query_report_url_code)
             wide_console.print(f"└──FULL REPORT: {report_url}", overflow="ellipsis")
@@ -336,7 +343,6 @@ def __process_model(
             report.markdown_text
             + f"\n <b>{report_stats.total_impacted_assets}</b> assets and <b>{report_stats.total_impacted_users}</b> people impacted \n\n\n"
         )
-
         rows = []
 
         for platform, impact in report_stats.impact_per_platform.items():
@@ -358,7 +364,8 @@ def __process_model(
 
 
 def run_check_sql_impact_analysis(
-    file_names: List, manifest_file: str, platform_id: str
+    file_names: List,
+    manifest_file: str,
 ) -> None:
     root_dir = os.getcwd()
     if settings.debug:
@@ -379,8 +386,4 @@ def run_check_sql_impact_analysis(
         exit(1)
 
     if manifest:
-        exit(
-            check_sql_impact_analysis(
-                paths=file_names, manifest=manifest, platform_id=platform_id
-            )
-        )
+        exit(check_sql_impact_analysis(paths=file_names, manifest=manifest))
