@@ -33,6 +33,7 @@ if os.path.exists(USER_CONFIG):
         if current_active_profile:
             current_config_items.update({k: v})
 
+PLATFORM_ID_FROM_CONFIG = current_config_items.get("alvin_platform_id", None)
 
 CONFIG_FILE_PATH = (
     current_config_items["config_file_path"]
@@ -152,8 +153,8 @@ FILE_NAME = typer.Option(
 )
 
 PLATFORM_ID = (
-    current_config_items["platform_id"]
-    if "platform_id" in current_config_items
+    current_config_items["alvin_platform_id"]
+    if "alvin_platform_id" in current_config_items
     else typer.Option(
         ...,
         "--platform-id",
